@@ -1,5 +1,5 @@
 `adonis` <-
-    function(formula, data=NULL, permutations=5, method="bray", strata=NULL,
+    function(formula, data=NULL, permutations=999, method="bray", strata=NULL,
              contr.unordered="contr.sum", contr.ordered="contr.poly",
              ...)
 {
@@ -7,7 +7,13 @@
     ## frame or a matrix, and A, B, and C may be factors or continuous
     ## variables.  data is the data frame from which A, B, and C would
     ## be drawn.
-  TOL <- 1e-7
+    TOL <- 1e-7
+    ## Set no. of permutations to x-1 if x is an even hundred
+    if (permutations %% 100 == 0) {
+        permutations <- permutations - 1
+        warning("Setting no. of permutations to ", permutations)
+    }
+    Terms <- terms(formula, data = data)
     lhs <- formula[[2]]
     lhs <- eval(lhs, data, parent.frame()) # to force evaluation 
     formula[[2]] <- NULL                # to remove the lhs
@@ -74,15 +80,13 @@
     ## Permutations
     if (missing(strata)) 
         strata <- NULL
-    G.p <- lapply(1:permutations, function(x) {
-        permutes <- permuted.index(n, strata = strata)
-        G[permutes, permutes]
-    } )
+    p <- sapply(1:permutations,
+                function(x) permuted.index(n, strata=strata))
     
-    ## SS.s <- sapply(G.p, function(Gs) { SS.perms(H, Gs, I) } )
+    ## Apply permutations for each term
     f.perms <- sapply(1:nterms, function(i) {
         sapply(1:permutations, function(j) {
-            f.test(H.s[[i]], G.p[[j]], I, df.Exp[i], df.Res, H.snterm)
+            f.test(H.s[[i]], G[p[,j],p[,j]], I, df.Exp[i], df.Res, H.snterm)
         } )
     })
   
@@ -92,13 +96,13 @@
                       MeanSqs = c(SS.Exp.each/df.Exp, SS.Res/df.Res, NA),
                       F.Model = c(F.Mod, NA,NA),
                       R2 = SumsOfSqs/SumsOfSqs[length(SumsOfSqs)],
-                      P = c(rowSums(t(f.perms) > F.Mod)/permutations, NA, NA))
+                      P = c((rowSums(t(f.perms) > F.Mod)+1)/(permutations+1), NA, NA))
     rownames(tab) <- c(attr(attr(rhs.frame, "terms"), "term.labels")[u.grps],
                        "Residuals", "Total")
     colnames(tab)[ncol(tab)] <- "Pr(>F)"
     out <- list(aov.tab = tab, call = match.call(), 
                 coefficients = beta.spp, coef.sites = beta.sites,
-                f.perms = f.perms, design.matrix = rhs)
+                f.perms = f.perms, model.matrix = rhs, terms = Terms)
     class(out) <- "adonis"
     out
 }
