@@ -8,6 +8,14 @@ function (x, digits = max(3, getOption("digits") - 3), ...)
     cat(deparse(x$call), "\n\n") 
     cat("Dissimilarity index:", x$distance, "\n")
     cat("Weights for groups: ", switch(x$weight.type, "n", "n-1", "n(n-1)", "n(n-1)/2"), "\n\n")
+    cat("Class means and counts:\n\n")
+    print(noquote(rbind("delta" = formatC(x$classdelta, digits = digits),
+                        "n" = formatC(x$n, digits=0))))
+    cat("\n")
+    if (!is.na(x$CS)) {
+        cat("Classification strength: ")
+        cat(formatC(x$CS, digits = digits), "\n")
+    }
     cat("Chance corrected within-group agreement A: ")
     cat(formatC(x$A, digits = digits), "\n")
     cat("Based on observed delta", formatC(x$delta), "and expected delta",
@@ -23,4 +31,3 @@ function (x, digits = max(3, getOption("digits") - 3), ...)
     cat("\n\n")
     invisible(x)
 }
-
